"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.payout_details_dto import PayoutDetailsDto
from eis.claim.model.regress_details_dto import RegressDetailsDto
from eis.claim.model.reserve_details_dto import ReserveDetailsDto
globals()['PayoutDetailsDto'] = PayoutDetailsDto
globals()['RegressDetailsDto'] = RegressDetailsDto
globals()['ReserveDetailsDto'] = ReserveDetailsDto
from eis.claim.model.create_regulation_item_request_dto import CreateRegulationItemRequestDto


class TestCreateRegulationItemRequestDto(unittest.TestCase):
    """CreateRegulationItemRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateRegulationItemRequestDto(self):
        """Test CreateRegulationItemRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateRegulationItemRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.update_payout_details_dto import UpdatePayoutDetailsDto
from eis.claim.model.update_reserve_details_dto import UpdateReserveDetailsDto
globals()['UpdatePayoutDetailsDto'] = UpdatePayoutDetailsDto
globals()['UpdateReserveDetailsDto'] = UpdateReserveDetailsDto
from eis.claim.model.update_regulation_item_request_dto_rest import UpdateRegulationItemRequestDtoRest


class TestUpdateRegulationItemRequestDtoRest(unittest.TestCase):
    """UpdateRegulationItemRequestDtoRest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateRegulationItemRequestDtoRest(self):
        """Test UpdateRegulationItemRequestDtoRest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdateRegulationItemRequestDtoRest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.claim
from eis.claim.api.claim_partner_roles_api import ClaimPartnerRolesApi  # noqa: E501


class TestClaimPartnerRolesApi(unittest.TestCase):
    """ClaimPartnerRolesApi unit test stubs"""

    def setUp(self):
        self.api = ClaimPartnerRolesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_claim_partner_role(self):
        """Test case for create_claim_partner_role

        Create the claim partner role  # noqa: E501
        """
        pass

    def test_delete_claim_partner_role(self):
        """Test case for delete_claim_partner_role

        Delete the claim partner role  # noqa: E501
        """
        pass

    def test_get_claim_partner_role(self):
        """Test case for get_claim_partner_role

        Retrieve the claim partner role  # noqa: E501
        """
        pass

    def test_list_claim_partner_role(self):
        """Test case for list_claim_partner_role

        List claim partner roles  # noqa: E501
        """
        pass

    def test_update_claim_partner_role(self):
        """Test case for update_claim_partner_role

        Update the claim partner role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.settlement_class import SettlementClass
globals()['SettlementClass'] = SettlementClass
from eis.claim.model.list_settlements_response_class import ListSettlementsResponseClass


class TestListSettlementsResponseClass(unittest.TestCase):
    """ListSettlementsResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListSettlementsResponseClass(self):
        """Test ListSettlementsResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListSettlementsResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.claim
from eis.claim.model.claim_status_class import ClaimStatusClass


class TestClaimStatusClass(unittest.TestCase):
    """ClaimStatusClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClaimStatusClass(self):
        """Test ClaimStatusClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClaimStatusClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.claim.api_client import ApiClient, Endpoint as _Endpoint
from eis.claim.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.claim.model.create_settlement_request_dto import CreateSettlementRequestDto
from eis.claim.model.create_settlement_response_class import CreateSettlementResponseClass
from eis.claim.model.get_settlement_response_class import GetSettlementResponseClass
from eis.claim.model.list_settlements_response_class import ListSettlementsResponseClass
from eis.claim.model.update_settlement_request_dto import UpdateSettlementRequestDto
from eis.claim.model.update_settlement_response_class import UpdateSettlementResponseClass


class SettlementsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_settlement_endpoint = _Endpoint(
            settings={
                'response_type': (CreateSettlementResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/v1/settlements',
                'operation_id': 'create_settlement',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'create_settlement_request_dto',
                    'authorization',
                ],
                'required': [
                    'create_settlement_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'create_settlement_request_dto':
                        (CreateSettlementRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'create_settlement_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_settlement_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/v1/settlements/{code}',
                'operation_id': 'delete_settlement',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'authorization',
                ],
                'required': [
                    'code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'code': 'code',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'code': 'path',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_settlement_endpoint = _Endpoint(
            settings={
                'response_type': (GetSettlementResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/v1/settlements/{code}',
                'operation_id': 'get_settlement',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'authorization',
                ],
                'required': [
                    'code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'code': 'code',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'code': 'path',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_settlements_endpoint = _Endpoint(
            settings={
                'response_type': (ListSettlementsResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/v1/settlements',
                'operation_id': 'list_settlements',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'authorization',
                    'page_size',
                    'page_token',
                    'filter',
                    'search',
                    'order',
                    'expand',
                    'filters',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'authorization':
                        (str,),
                    'page_size':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'page_token':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'filter':
                        (str,),
                    'search':
                        (bool, date, datetime, dict, float, int, list, str, none_type,),
                    'order':
                        (str,),
                    'expand':
                        (str,),
                    'filters':
                        (str,),
                },
                'attribute_map': {
                    'authorization': 'Authorization',
                    'page_size': 'pageSize',
                    'page_token': 'pageToken',
                    'filter': 'filter',
                    'search': 'search',
                    'order': 'order',
                    'expand': 'expand',
                    'filters': 'filters',
                },
                'location_map': {
                    'authorization': 'header',
                    'page_size': 'query',
                    'page_token': 'query',
                    'filter': 'query',
                    'search': 'query',
                    'order': 'query',
                    'expand': 'query',
                    'filters': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_settlement_endpoint = _Endpoint(
            settings={
                'response_type': (UpdateSettlementResponseClass,),
                'auth': [
                    'bearer'
                ],
                'endpoint_path': '/v1/settlements/{code}',
                'operation_id': 'update_settlement',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'code',
                    'update_settlement_request_dto',
                    'authorization',
                ],
                'required': [
                    'code',
                    'update_settlement_request_dto',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'code':
                        (str,),
                    'update_settlement_request_dto':
                        (UpdateSettlementRequestDto,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'code': 'code',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'code': 'path',
                    'update_settlement_request_dto': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def create_settlement(
        self,
        create_settlement_request_dto,
        **kwargs
    ):
        """Create the settlement  # noqa: E501

        This will create a settlement against a claim in the database  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_settlement(create_settlement_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            create_settlement_request_dto (CreateSettlementRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CreateSettlementResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['create_settlement_request_dto'] = \
            create_settlement_request_dto
        return self.create_settlement_endpoint.call_with_http_info(**kwargs)

    def delete_settlement(
        self,
        code,
        **kwargs
    ):
        """Delete the settlement  # noqa: E501

        This will delete the requested settlement from the database.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_settlement(code, async_req=True)
        >>> result = thread.get()

        Args:
            code (str):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        return self.delete_settlement_endpoint.call_with_http_info(**kwargs)

    def get_settlement(
        self,
        code,
        **kwargs
    ):
        """Retrieve the settlement  # noqa: E501

        Retrieves the details of the settlement that was previously created. Supply the unique settlement code        that was returned when you created it and Emil Api will return the corresponding settlement information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_settlement(code, async_req=True)
        >>> result = thread.get()

        Args:
            code (str):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetSettlementResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        return self.get_settlement_endpoint.call_with_http_info(**kwargs)

    def list_settlements(
        self,
        **kwargs
    ):
        """List settlements  # noqa: E501

        Returns a list of settlements you have previously created.          The settlements are returned in sorted order, with the oldest one appearing first.          For more information about pagination, read the Pagination documentation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_settlements(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            page_size (bool, date, datetime, dict, float, int, list, str, none_type): A limit on the number of objects to be returned.     Limit ranges between 1 and 50. Default: 10.. [optional]
            page_token (bool, date, datetime, dict, float, int, list, str, none_type): A cursor for use in pagination.     pageToken is an ID that defines your place in the list.     For instance, if you make a list request and receive 100 objects and pageToken=1,     your subsequent call can include pageToken=2 in order to fetch the next page of the list.. [optional]
            filter (str): Filter the response by one or multiple fields.            In general, fetching filtered responses will conserve bandwidth and reduce response time.<br/>           <br/>           <i>Allowed values: policyNumber, productId, accountCode, claimCode, InsuredObjectId</i>. [optional]
            search (bool, date, datetime, dict, float, int, list, str, none_type): To search the list by any field, pass search=xxx to fetch the result.. [optional]
            order (str): Order allows you to specify the desired order of entities retrieved from the server by           ascending (ASC) or descending (DESC) order.<br/>           <br/>           <i>Allowed values: insuredObject, reserve, payment, recourse</i>. [optional]
            expand (str): Expand to fetch additional information about the list items.           Expanding resources can reduce the number of API calls required to accomplish a task.           Use with discretion as some expanded fields can drastically increase payload size.<br/>           <br/>           <i>Allowed values: claims.<i>. [optional]
            filters (str): Filters the response by one or multiple fields.            Advanced filter functionality allows you to perform more complex filtering operations.<br/>           <br/>           <i>Allowed values: policyNumber, productId, accountCode, claimCode, InsuredObjectId</i>. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ListSettlementsResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_settlements_endpoint.call_with_http_info(**kwargs)

    def update_settlement(
        self,
        code,
        update_settlement_request_dto,
        **kwargs
    ):
        """Update the settlement  # noqa: E501

        Updates the specified settlement by setting the values of the parameters passed. Any parameters not provided will be left unchanged.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_settlement(code, update_settlement_request_dto, async_req=True)
        >>> result = thread.get()

        Args:
            code (str):
            update_settlement_request_dto (UpdateSettlementRequestDto):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            UpdateSettlementResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['code'] = \
            code
        kwargs['update_settlement_request_dto'] = \
            update_settlement_request_dto
        return self.update_settlement_endpoint.call_with_http_info(**kwargs)




"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.claim
from eis.claim.api.settlements_api import SettlementsApi  # noqa: E501


class TestSettlementsApi(unittest.TestCase):
    """SettlementsApi unit test stubs"""

    def setUp(self):
        self.api = SettlementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_settlement(self):
        """Test case for create_settlement

        Create the settlement  # noqa: E501
        """
        pass

    def test_delete_settlement(self):
        """Test case for delete_settlement

        Delete the settlement  # noqa: E501
        """
        pass

    def test_get_settlement(self):
        """Test case for get_settlement

        Retrieve the settlement  # noqa: E501
        """
        pass

    def test_list_settlements(self):
        """Test case for list_settlements

        List settlements  # noqa: E501
        """
        pass

    def test_update_settlement(self):
        """Test case for update_settlement

        Update the settlement  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
